@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.56';
+our $VERSION = '0.58';
 
 use Exporter qw( import );
 
@@ -110,7 +110,7 @@ List::SomeUtils - Provide the stuff missing in List::Util
 
 =head1 VERSION
 
-version 0.56
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -293,10 +293,13 @@ Evaluation of BLOCK will immediately stop at the second true value.
 
 =head3 apply BLOCK LIST
 
-Applies BLOCK to each item in LIST and returns a list of the values after BLOCK
-has been applied. In scalar context, the last element is returned.  This
-function is similar to C<map> but will not modify the elements of the input
-list:
+Makes a copy of the list and then passes each element I<from the copy> to the
+BLOCK. Any changes or assignments to C<$_> in the BLOCK will only affect the
+elements of the new list. However, if C<$_> is a reference then changes to the
+referenced value will be seen in both the original and new list.
+
+This function is similar to C<map> but will not modify the elements of the
+input list:
 
   my @list = (1 .. 4);
   my @mult = apply { $_ *= 2 } @list;
@@ -310,6 +313,15 @@ Think of it as syntactic sugar for
 
   for (my @mult = @list) { $_ *= 2 }
 
+Note that you must alter C<$_> directly inside BLOCK in order for changes to
+make effect. New value returned from the BLOCK are ignored:
+
+  # @new is identical to @list.
+  my @new = apply { $_ * 2 } @list;
+
+  # @new is different from @list
+  my @new = apply { $_ =* 2 } @list;
+
 =head3 insert_after BLOCK VALUE LIST
 
 Inserts VALUE after the first item in LIST for which the criterion in BLOCK is
@@ -446,7 +458,7 @@ Negative values are only ok when they refer to a partition previously created:
 
   my @idx  = ( 0, 1, -1 );
   my $i    = 0;
-  my @part = part { $idx[$++ % 3] } 1 .. 8; # [1, 4, 7], [2, 3, 5, 6, 8]
+  my @part = part { $idx[$i++ % 3] } 1 .. 8; # [1, 4, 7], [2, 3, 5, 6, 8]
 
 =head2 Iteration
 
@@ -706,8 +718,8 @@ If more than one item appears the same number of times in the list, all such
 items will be returned. For example, the mode of a unique list is the list
 itself.
 
-This function B<always> returns a list. That means that in scalar context you
-get a count indicating the number of modes in the list.
+This function returns a list in list context. In scalar context it returns a
+count indicating the number of modes in the list.
 
 =head1 MAINTENANCE
 
@@ -901,7 +913,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Aaron Crane BackPan Brad Forschinger David Golden jddurand Jens Rehsack J.R. Mash Karen Etheridge Ricardo Signes Toby Inkster Tokuhiro Matsuno Tom Wyant
+=for stopwords Aaron Crane BackPan bay-max1 Brad Forschinger David Golden jddurand Jens Rehsack J.R. Mash Karen Etheridge Ricardo Signes Toby Inkster Tokuhiro Matsuno Tom Wyant
 
 =over 4
 
@@ -915,6 +927,10 @@ BackPan <BackPan>
 
 =item *
 
+bay-max1 <34803732+bay-max1@users.noreply.github.com>
+
+=item *
+
 Brad Forschinger <bnjf@bnjf.id.au>
 
 =item *
@@ -957,7 +973,7 @@ Tom Wyant <wyant@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dave Rolsky <autarch@urth.org>.
+This software is copyright (c) 2019 by Dave Rolsky <autarch@urth.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
